@@ -15,6 +15,8 @@ from wx import RED
 from wx import RED_PEN
 from wx import WHITE_BRUSH
 
+from deprecated import deprecated
+
 from miniogl.ShapeModel import ShapeModel
 
 from ogl.preferences.OglPreferences import OglPreferences
@@ -72,6 +74,14 @@ class Shape:
                 t: TextShape = self.AddText(0, -10, str(self._id))
                 t.SetColor(RED)
 
+    @property
+    def id(self) -> int:
+        return self._id
+
+    @id.setter
+    def id(self, newValue: int):
+        self._id = newValue
+
     def SetPen(self, pen: Pen):
         """
         Set the pen used to draw the shape.
@@ -104,16 +114,21 @@ class Shape:
         """
         return self._brush
 
+    @deprecated(reason='Use the .id property')
     def GetID(self):
         """
+        TODO:  Make this a property
         Get the ID number of the shape.
 
         @return int
         """
         return self._id
 
+    @deprecated(reason='Use the .id property')
     def SetID(self, theId):
         """
+        TODO: Make this a property
+
         Set the ID of the shape. This can be used when loading a shape.
 
         @param theId
@@ -588,12 +603,12 @@ class Shape:
         # shape model (ShapeModel) given by the frame where the shape
         # is displayed.
         ratio = self.GetDiagram().GetPanel().GetCurrentZoom()
-        dx = self.GetDiagram().GetPanel().GetXOffset()
-        dy = self.GetDiagram().GetPanel().GetYOffset()
+        dx: int = round(self.GetDiagram().GetPanel().GetXOffset())
+        dy: int = round(self.GetDiagram().GetPanel().GetYOffset())
 
         # calculation of the shape (view) coordinates in the light of the offsets and ratio
-        x = (ratio * mx) + dx
-        y = (ratio * my) + dy
+        x: int = round(ratio * mx) + dx
+        y: int = round(ratio * my) + dy
 
         # assign the new coordinates to the shape (view). DON'T USE SetPosition(),
         # because there is a call to UpdateModel() in that method.
@@ -630,8 +645,8 @@ class Shape:
 
         # calculation of the model coordinates in the light of the
         # offsets and ratio and assignment.
-        mx = round(x - dx) // ratio
-        my = round(y - dy) // ratio
+        mx = round((x - dx) // ratio)
+        my = round((y - dy) // ratio)
         model.SetPosition(mx, my)
 
         # change also the position of the model of the children,
@@ -639,8 +654,8 @@ class Shape:
         # and so their update model is not called
         for child in self._anchors:
             cx, cy = child.GetPosition()
-            cmx = (cx - dx) // ratio
-            cmy = (cy - dy) // ratio
+            cmx = round((cx - dx) // ratio)
+            cmy = round((cy - dy) // ratio)
             child.GetModel().SetPosition(cmx, cmy)
 
     def GetModel(self):
