@@ -1,5 +1,6 @@
 
 from typing import List
+from typing import NewType
 from typing import Tuple
 
 from logging import Logger
@@ -26,12 +27,20 @@ from ogl.OglLink import OglLink
 from ogl.OglPosition import OglPosition
 from ogl.OglUtils import OglUtils
 
+SegmentPoint  = NewType('SegmentPoint', Tuple[int, int])
+SegmentPoints = NewType('SegmentPoints', List[SegmentPoint])
+
+DiamondPoint  = NewType('DiamondPoint', Tuple[int, int])
+DiamondPoints = NewType('DiamondPoints', List[DiamondPoint])
+
+PI_6:         float = pi / 6
+DIAMOND_SIZE: int = 7
+
 
 class OglAssociation(OglLink):
 
     TEXT_SHAPE_FONT_SIZE: int = 12
 
-    clsLogger: Logger = getLogger(__name__)
     """
     Graphical link representation of an association, (simple line, no arrow).
     To get a new link,  use the `OglLinkFactory` and specify
@@ -47,6 +56,8 @@ class OglAssociation(OglLink):
             srcPos:     Position of source      Override location of input source
             dstPos:     Position of destination Override location of input destination
         """
+        self.oglAssociationLogger: Logger = getLogger(__name__)
+
         super().__init__(srcShape, pyutLink, dstShape, srcPos=srcPos, dstPos=dstPos)
 
         self._centerLabel:            OglAssociationLabel = OglAssociationLabel()
@@ -103,47 +114,20 @@ class OglAssociation(OglLink):
         self._drawCenterLabel(dc=dc, sp=oglSp, dp=oglDp)
         self._drawDestinationCardinality(dc=dc, sp=oglSp, dp=oglDp)
 
-    def drawLosange(self, dc: DC, filled: bool = False):
+    def drawDiamond(self, dc: DC, filled: bool = False):
         """
         Draw an arrow at the beginning of the line.
 
         Args:
             dc:         The device context
-            filled:     True if the losange must be filled, False otherwise
-
-        Note:  Losange is French for 'diamond'
+            filled:     True if the diamond must be filled, False otherwise
         """
-        pi_6 = pi / 6
-
+        #
         line = self.GetSegments()
-        x1, y1 = line[1]
-        x2, y2 = line[0]
-        a: int = x2 - x1
-        b: int = y2 - y1
-        if abs(a) < 0.01:  # vertical segment
-            if b > 0:
-                alpha: float = -pi / 2
-            else:
-                alpha = pi / 2
-        else:
-            if a == 0:
-                if b > 0:
-                    alpha = pi / 2
-                else:
-                    alpha = 3 * pi / 2
-            else:
-                alpha = atan(b/a)
-        if a > 0:
-            alpha += pi
-        alpha1: float = alpha + pi_6
-        alpha2: float = alpha - pi_6
-        size:   int   = 8               # TODO:  Fix this magic number
 
-        points: List[Tuple[int, int]] = [
-            (x2 + round(size * cos(alpha1)), y2 + round(size * sin(alpha1))), (x2, y2),
-            (x2 + round(size * cos(alpha2)), y2 + round(size * sin(alpha2))),
-            (x2 + 2 * round(size * cos(alpha)), y2 + 2 * round(size * sin(alpha)))
-                                         ]
+        # self.oglAssociationLogger.debug(f'{line=}')
+        points: DiamondPoints = OglAssociation.calculateDiamondPoints(lineSegments=line)
+        # self.oglAssociationLogger.debug(f'{points:}')
 
         dc.SetPen(BLACK_PEN)
         if filled:
@@ -174,7 +158,7 @@ class OglAssociation(OglLink):
         srcLblX: int = round((20 * dx / linkLength - dx * 5 / linkLength) + sp.x)
         srcLblY: int = round((20 * dy / linkLength + dy * 5 / linkLength) + sp.y)
 
-        if OglAssociation.clsLogger.isEnabledFor(INFO):
+        if self.oglAssociationLogger.isEnabledFor(INFO):
             info = (
                 f'{sp=} '
                 f'{dp=} '
@@ -184,7 +168,7 @@ class OglAssociation(OglLink):
                 f'srcLblX={srcLblX:.2f} '
                 f'srcLblY={srcLblY:.2f}'
             )
-            OglAssociation.clsLogger.info(info)
+            self.oglAssociationLogger.info(info)
         saveFont: Font = dc.GetFont()
         dc.SetFont(self._defaultFont)
 
@@ -220,5 +204,76 @@ class OglAssociation(OglLink):
 
         return associationLabel
 
+    @staticmethod
+    def calculateDiamondPoints(lineSegments: SegmentPoints) -> DiamondPoints:
+        """
+        Made static so that we can unit test it;  Please the only instance variables needed
+        are passed in
+
+        Args:
+            lineSegments:  The line where we are putting the diamondPoints
+
+        Returns:  The diamond points that define the diamond polygon
+        """
+        x1, y1 = lineSegments[1]
+        x2, y2 = lineSegments[0]
+        a: int = x2 - x1
+        b: int = y2 - y1
+        if abs(a) < 0.01:  # vertical segment
+            if b > 0:
+                alpha: float = -pi / 2
+            else:
+                alpha = pi / 2
+        else:
+            if a == 0:
+                if b > 0:
+                    alpha = pi / 2
+                else:
+                    alpha = 3 * pi / 2
+            else:
+                alpha = atan(b/a)
+        if a > 0:
+            alpha += pi
+        alpha1: float = alpha + PI_6
+        alpha2: float = alpha - PI_6
+
+        diamondPoints: DiamondPoints = DiamondPoints([])
+
+        dp0: DiamondPoint = OglAssociation.calculateDiamondPoint0(x2=x2, y2=y2, alpha1=alpha1)
+        diamondPoints.append(dp0)
+
+        diamondPoints.append(DiamondPoint((x2, y2)))
+
+        dp2: DiamondPoint = OglAssociation.calculateDiamondPoint2(x2=x2, y2=y2, alpha2=alpha2)
+        diamondPoints.append(dp2)
+
+        dp3: DiamondPoint = OglAssociation.calculateDiamondPoint3(x2=x2, y2=y2, alpha=alpha)
+        diamondPoints.append(dp3)
+
+        return diamondPoints
+
+    @classmethod
+    def calculateDiamondPoint0(cls, x2: float, y2: float, alpha1: float) -> DiamondPoint:
+        dpx0: float = x2 + DIAMOND_SIZE * cos(alpha1)
+        dpy0: float = y2 + DIAMOND_SIZE * sin(alpha1)
+
+        return DiamondPoint((round(dpx0), round(dpy0)))
+
+    @classmethod
+    def calculateDiamondPoint2(cls, x2: float, y2: float, alpha2: float) -> DiamondPoint:
+
+        dpx2: float = x2 + DIAMOND_SIZE * cos(alpha2)
+        dpy2: float = y2 + DIAMOND_SIZE * sin(alpha2)
+
+        return DiamondPoint((round(dpx2), round(dpy2)))
+
+    @classmethod
+    def calculateDiamondPoint3(cls, x2: float, y2: float, alpha: float) -> DiamondPoint:
+
+        dpx3: float = x2 + 2 * DIAMOND_SIZE * cos(alpha)
+        dpy3: float = y2 + 2 * DIAMOND_SIZE * sin(alpha)
+
+        return DiamondPoint((round(dpx3), round(dpy3)))
+
     def __repr__(self):
-        return f'OglAssociation - from: {self.getSourceShape()} to: {self.getDestinationShape()}'
+        return f'OglAssociation - {super().__repr__()}'
