@@ -13,7 +13,6 @@ from wx import WHITE_BRUSH
 
 from pyutmodel.PyutLink import PyutLink
 
-
 from ogl.OglLink import OglLink
 from ogl.OglClass import OglClass
 
@@ -55,16 +54,8 @@ class OglInterface(OglLink):
     def updateLabels(self):
         """
         Update the labels according to the link.
-
-        @since 1.14
-        @author Laurent Burgbacher <lb@alawa.ch>
         """
         def prepareLabel(textShape, text):
-            """
-            Update a label.
-
-            @author Laurent Burgbacher <lb@alawa.ch>
-            """
             # If label should be drawn
             if text.strip() != "":
                 textShape.SetText(text)
@@ -125,3 +116,6 @@ class OglInterface(OglLink):
 
             if withChildren is True:
                 self.DrawChildren(dc)
+
+    def __repr__(self):
+        return f'OglInterface - {super().__repr__()}'
